# Example datasets for aseg_gdf2

These are test datasets for [aseg_gdf2](http://github.com/kinverarity1/aseg_gdf2). Most of them have been truncated to reduce their size.

- [GA1286_Waveforms](3bcfc711) - CC BY 4.0 - [East Isa VTEM Plus helicopter-borne versatile time domain electromagnetic and magnetic geophysical survey (Geoscience Australia)](https://ecat.ga.gov.au/geonetwork/srv/eng/catalog.search#/metadata/3bcfc711-6549-400d-b3a2-9deb8ac90825)
- [Mugrave_WB_MGA52](9a13704a) - CC BY 4.0 - [SkyTEM helicopter Airborne Electromagnetic Survey Musgrave Region, South Australia 2016- Contractor supplied data and conductivity depth transforms (Geoscience Australia)](https://ecat.ga.gov.au/geonetwork/srv/eng/catalog.search#/metadata/9a13704a-918c-4713-83fd-6c1a4b36ac9f)
- [AusAEM_02_NT&WA_AEM_Tranche1_GA_vsum_inversion](8e598964) - CC BY 4.0 - [AusAEM 02 WA/NT 2019-20 Airborne Electromagnetic Survey (Geoscience Australia)](https://ecat.ga.gov.au/geonetwork/srv/eng/catalog.search#/metadata/8e598964-b4f3-4500-86ba-4c36d762f14e)